@@ -11,8 +11,9 @@
 
 namespace ld_estimator {
   // template <typename T>
-  std::pair<Haps<int>, int> tally_haplotypes(std::vector<std::vector<std::string> > & var1,
-      std::vector<std::vector<std::string> > & var2, std::vector<bool> & ploidy);
+std::pair<Haps<int>, int> tally_haplotypes(char ** a1s, char ** a2s,
+    char ** b1s, char ** b2s, int size, std::vector<bool> & ploidy,
+    const char * major_1, const char * minor_1, const char * major_2, const char * minor_2);
 }
 
 #endif
