@@ -1,6 +1,7 @@
 #ifndef LD_ESTIMATOR_UTILS_H
 #define LD_ESTIMATOR_UTILS_H
 
+#include <array>
 #include <vector>
 #include <string>
 #include <set>
@@ -11,9 +12,9 @@
 #include "haps.h"
 
 namespace ld_estimator {
-  bool is_monomorphic(std::vector<std::vector<std::string> > & var);
+  bool is_monomorphic(char ** a1, char ** a2, int size);
   bool lacks_haplotypes(Haps<int> & counts, int unknown);
-  std::vector<std::string> get_alleles(std::vector<std::vector<std::string> > & var);
+  void get_alleles(char ** a1, char ** a2, int size, std::vector<bool> & haploid, std::array<const char *, 2> & alleles);
 }
 
 #endif
